@@ -74,6 +74,9 @@ clean_names.character <- function(x, include_names = FALSE, ...) {
     return(x)
   }
   out <- sapply(x, function(.x) {
+    # in case we have ranges, like [2:5], remove those first, so it's not
+    # treated as "interaction"
+    .x <- sub("\\[(\\d+):(\\d+)\\]", "", .x)
     if (grepl(":", .x, fixed = TRUE) && !grepl("::", .x, fixed = TRUE)) {
       paste(sapply(
         strsplit(.x, ":", fixed = TRUE),
@@ -118,7 +121,7 @@ clean_names.character <- function(x, include_names = FALSE, ...) {
     "pspline", "scale-poly", "poly", "catg", "asis", "matrx", "pol", "strata",
     "strat", "scale", "scored", "interaction", "sqrt", "sin", "cos", "tan",
     "acos", "asin", "atan", "atan2", "exp", "lsp", "rcs", "pb", "lo",
-    "bs", "ns", "mSpline", "t2", "te", "ti", "tt", # need to be fixed first "mmc", "mm",
+    "bs", "ns", "mSpline", "bSpline", "t2", "te", "ti", "tt", # need to be fixed first "mmc", "mm",
     "mi", "mo", "gp", "s", "I"
   )
 
