@@ -15,22 +15,25 @@
 #' @param x A fitted model.
 #' @inheritParams find_parameters
 #'
-#' @return A data frame with "cleaned" parameter names and information on
-#'   effects, component and group where parameters belong to. To be consistent
-#'   across different models, the returned data frame always has at least four
-#'   columns `Parameter`, `Effects`, `Component` and
-#'   `Cleaned_Parameter`. See 'Details'.
+#' @return
 #'
-#' @details The `Effects` column indicate if a parameter is a *fixed*
-#' or *random* effect. The `Component` can either be *conditional*
-#' or *zero_inflated*. For models with random effects, the `Group`
-#' column indicates the grouping factor of the random effects. For multivariate
-#' response models from \pkg{brms} or \pkg{rstanarm}, an additional *Response*
-#' column is included, to indicate which parameters belong to which response
-#' formula. Furthermore, *Cleaned_Parameter* column is returned that
-#' contains "human readable" parameter names (which are mostly identical to
-#' `Parameter`, except for for models from \pkg{brms} or \pkg{rstanarm},
-#' or for specific terms like smooth- or spline-terms).
+#' A data frame with "cleaned" parameter names and information on effects,
+#' component and group where parameters belong to. To be consistent across
+#' different models, the returned data frame always has at least four columns
+#' `Parameter`, `Effects`, `Component` and `Cleaned_Parameter`. See 'Details'.
+#'
+#' @details
+#'
+#' The `Effects` column indicate if a parameter is a *fixed* or *random* effect.
+#' The `Component` can either be *conditional* or *zero_inflated*. For models
+#' with random effects, the `Group` column indicates the grouping factor of the
+#' random effects. For multivariate response models from \pkg{brms} or
+#' \pkg{rstanarm}, an additional *Response* column is included, to indicate
+#' which parameters belong to which response formula. Furthermore,
+#' *Cleaned_Parameter* column is returned that contains "human readable"
+#' parameter names (which are mostly identical to `Parameter`, except for for
+#' models from \pkg{brms} or \pkg{rstanarm}, or for specific terms like smooth-
+#' or spline-terms).
 #'
 #' @examples
 #' \dontrun{
@@ -116,7 +119,7 @@ clean_parameters.default <- function(x, group = "", ...) {
     }
   })
 
-  out <- .remove_backticks_from_parameter_names(do.call(rbind, l))
+  out <- text_remove_backticks(do.call(rbind, l))
   out <- .remove_empty_columns_from_pars(out)
   .fix_random_effect_smooth(x, out)
 }
@@ -137,7 +140,7 @@ clean_parameters.emmGrid <- function(x, ...) {
     )
   })
 
-  out <- .remove_backticks_from_parameter_names(do.call(rbind, l))
+  out <- text_remove_backticks(do.call(rbind, l))
   out <- .remove_empty_columns_from_pars(out)
   out
 }
@@ -178,7 +181,7 @@ clean_parameters.BFBayesFactor <- function(x, ...) {
     )
   })
 
-  out <- .remove_backticks_from_parameter_names(do.call(rbind, l))
+  out <- text_remove_backticks(do.call(rbind, l))
   out <- .remove_empty_columns_from_pars(.clean_bfbayesfactor_params(out))
   .fix_random_effect_smooth(x, out)
 }
@@ -220,7 +223,7 @@ clean_parameters.wbm <- function(x, ...) {
     )
   })
 
-  out <- .remove_backticks_from_parameter_names(do.call(rbind, l))
+  out <- text_remove_backticks(do.call(rbind, l))
   out <- .remove_empty_columns_from_pars(out)
   .fix_random_effect_smooth(x, out)
 }
@@ -263,7 +266,7 @@ clean_parameters.glmm <- function(x, ...) {
     )
   })
 
-  out <- .remove_backticks_from_parameter_names(do.call(rbind, l))
+  out <- text_remove_backticks(do.call(rbind, l))
   .remove_empty_columns_from_pars(out)
 }
 
@@ -410,7 +413,7 @@ clean_parameters.mlm <- function(x, ...) {
     )
   })
 
-  out <- .remove_backticks_from_parameter_names(do.call(rbind, l))
+  out <- text_remove_backticks(do.call(rbind, l))
   out <- .remove_empty_columns_from_pars(out)
   .fix_random_effect_smooth(x, out)
 }
