@@ -27,6 +27,34 @@ find_statistic <- function(x, ...) {
     stop("The entered object is not a model object.", call. = FALSE)
   }
 
+  # handle 'htest' objects specifically
+  if (inherits(x, "htest")) {
+    if (x$method == "Fisher's Exact Test for Count Data") {
+      stat <- "p-value"
+    } else if (x$method == "Wilcoxon signed rank test with continuity correction") {
+      stat <- "z-statistic"
+    } else {
+      stat <- switch(
+        names(x$statistic),
+        t = "t-statistic",
+        Z = "z-statistic",
+        `Quade F` = ,
+        `F` = "F-statistic",
+        `Bartlett's K-squared` = ,
+        `Fligner-Killeen:med chi-squared` = ,
+        `Friedman chi-squared` = ,
+        `Kruskal-Wallis chi-squared` = ,
+        `Cochran-Mantel-Haenszel M^2` = ,
+        `McNemar's chi-squared` = ,
+        `X-squared` = "chi-squared statistic",
+        `number of successes` = "number of successes",
+        `number of events` = "number of events",
+        paste(names(x$statistic), "statistic")
+      )
+    }
+    return(stat)
+  }
+
   if (inherits(x, "mipo")) {
     x <- tryCatch(
       {
@@ -60,7 +88,7 @@ find_statistic <- function(x, ...) {
   # t-value objects ----------------------------------------------------------
 
   t.mods <- c(
-    "bayesx", "BBreg", "BBmm", "bcplm", "biglm", "blmerMod",
+    "bayesx", "BBreg", "BBmm", "bcplm", "biglm", "bfsl", "blmerMod",
     "cch", "censReg", "complmrob", "cpglm", "cpglmm", "crq", "crqs",
     "drc",
     "elm",
@@ -192,13 +220,15 @@ find_statistic <- function(x, ...) {
 
   # edge cases ---------------------------------------------------------------
 
+  m_info <- model_info(x, verbose = FALSE, return_family_only = TRUE)
+
   # tweedie-check needs to come first, because glm can also have tweedie
   # family, so this exception needs to be caught before checking for g.mods
 
   tryCatch(
     {
       suppressWarnings(
-        if (!is_multivariate(x) && model_info(x)$is_tweedie) {
+        if (!is_multivariate(x) && .is_tweedie(x, m_info)) {
           return("t-statistic")
         }
       )
@@ -246,7 +276,7 @@ find_statistic <- function(x, ...) {
         }
       )
       return(stat)
-    } else if (model_info(x)$family %in% g.t.mods) {
+    } else if (m_info$family %in% g.t.mods) {
       return("t-statistic")
     } else {
       return("z-statistic")
@@ -304,3 +334,17 @@ find_statistic <- function(x, ...) {
     }
   }
 }
+
+
+
+
+
+# helper ---------------
+
+.is_tweedie <- function(model, info) {
+  if (info$family %in% c("Student's-t", "t Family", "gaussian", "Gaussian") || grepl("(\\st)$", info$family)) {
+    linear_model <- TRUE
+  }
+  tweedie_fam <- grepl("^(tweedie|Tweedie)", info$family) | grepl("^(tweedie|Tweedie)", info$link_function)
+  (linear_model && tweedie_fam) || inherits(model, c("bcplm", "cpglm", "cpglmm", "zcpglm"))
+}
