@@ -72,7 +72,7 @@ get_parameters.default <- function(x, verbose = TRUE, ...) {
         row.names = NULL
       )
 
-      .remove_backticks_from_parameter_names(params)
+      text_remove_backticks(params)
     },
     error = function(x) {
       if (isTRUE(verbose)) {
@@ -95,7 +95,7 @@ get_parameters.summary.lm <- function(x, ...) {
     row.names = NULL
   )
 
-  .remove_backticks_from_parameter_names(params)
+  text_remove_backticks(params)
 }
 
 
@@ -124,6 +124,21 @@ get_parameters.model_fit <- function(x, ...) {
 }
 
 
+#' @export
+get_parameters.bfsl <- function(x, ...) {
+  cf <- stats::coef(x)
+
+  params <- data.frame(
+    Parameter = rownames(cf),
+    Estimate = unname(cf[, "Estimate"]),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  text_remove_backticks(params)
+}
+
+
 #' @export
 get_parameters.selection <- function(x, component = c("all", "selection", "outcome", "auxiliary"), ...) {
   component <- match.arg(component)
@@ -144,7 +159,7 @@ get_parameters.selection <- function(x, component = c("all", "selection", "outco
     params <- params[params$Component == component, , drop = FALSE]
   }
 
-  .remove_backticks_from_parameter_names(params)
+  text_remove_backticks(params)
 }
 
 
@@ -160,7 +175,7 @@ get_parameters.epi.2by2 <- function(x, ...) {
     stringsAsFactors = FALSE,
     row.names = NULL
   )
-  .remove_backticks_from_parameter_names(params)
+  text_remove_backticks(params)
 }
 
 
@@ -173,7 +188,7 @@ get_parameters.Rchoice <- function(x, ...) {
     stringsAsFactors = FALSE,
     row.names = NULL
   )
-  .remove_backticks_from_parameter_names(params)
+  text_remove_backticks(params)
 }
 
 
@@ -186,13 +201,13 @@ get_parameters.btergm <- function(x, ...) {
     stringsAsFactors = FALSE,
     row.names = NULL
   )
-  .remove_backticks_from_parameter_names(params)
+  text_remove_backticks(params)
 }
 
 
 #' @export
 get_parameters.mediate <- function(x, ...) {
-  info <- model_info(x$model.y)
+  info <- model_info(x$model.y, verbose = FALSE)
   if (info$is_linear && !x$INT) {
     out <- data.frame(
       Parameter = c("ACME", "ADE", "Total Effect", "Prop. Mediated"),
@@ -211,7 +226,7 @@ get_parameters.mediate <- function(x, ...) {
       stringsAsFactors = FALSE
     )
   }
-  .remove_backticks_from_parameter_names(out)
+  text_remove_backticks(out)
 }
 
 
@@ -222,7 +237,7 @@ get_parameters.ridgelm <- function(x, ...) {
     Estimate = as.vector(x$coef),
     stringsAsFactors = FALSE
   )
-  .remove_backticks_from_parameter_names(out)
+  text_remove_backticks(out)
 }
 
 
@@ -233,7 +248,7 @@ get_parameters.ivFixed <- function(x, ...) {
     Estimate = as.vector(x$coefficients),
     stringsAsFactors = FALSE
   )
-  .remove_backticks_from_parameter_names(out)
+  text_remove_backticks(out)
 }
 
 
@@ -244,7 +259,7 @@ get_parameters.ivprobit <- function(x, ...) {
     Estimate = as.vector(x$coefficients),
     stringsAsFactors = FALSE
   )
-  .remove_backticks_from_parameter_names(out)
+  text_remove_backticks(out)
 }
 
 
@@ -256,7 +271,7 @@ get_parameters.survreg <- function(x, ...) {
     Estimate = as.vector(s$table[, 1]),
     stringsAsFactors = FALSE
   )
-  .remove_backticks_from_parameter_names(out)
+  text_remove_backticks(out)
 }
 
 
@@ -268,7 +283,7 @@ get_parameters.riskRegression <- function(x, ...) {
     Estimate = as.numeric(cs[, 2]),
     stringsAsFactors = FALSE
   )
-  .remove_backticks_from_parameter_names(out)
+  text_remove_backticks(out)
 }
 
 
@@ -279,7 +294,7 @@ get_parameters.mipo <- function(x, ...) {
     Estimate = as.vector(summary(x)$estimate),
     stringsAsFactors = FALSE
   )
-  .remove_backticks_from_parameter_names(out)
+  text_remove_backticks(out)
 }
 
 
@@ -308,7 +323,7 @@ get_parameters.margins <- function(x, ...) {
     Estimate = as.vector(summary(x)$AME),
     stringsAsFactors = FALSE
   )
-  .remove_backticks_from_parameter_names(out)
+  text_remove_backticks(out)
 }
 
 
@@ -325,7 +340,7 @@ get_parameters.glht <- function(x, ...) {
     Estimate = unname(s$test$coefficients),
     stringsAsFactors = FALSE
   )
-  .remove_backticks_from_parameter_names(out)
+  text_remove_backticks(out)
 }
 
 
@@ -342,7 +357,7 @@ get_parameters.mle2 <- function(x, ...) {
     row.names = NULL
   )
 
-  .remove_backticks_from_parameter_names(params)
+  text_remove_backticks(params)
 }
 
 #' @export
@@ -363,7 +378,7 @@ get_parameters.lrm <- function(x, ...) {
         row.names = NULL
       )
 
-      .remove_backticks_from_parameter_names(params)
+      text_remove_backticks(params)
     },
     error = function(x) {
       NULL
@@ -400,7 +415,7 @@ get_parameters.multinom <- function(x, ...) {
     )
   }
 
-  .remove_backticks_from_parameter_names(out)
+  text_remove_backticks(out)
 }
 
 
@@ -423,7 +438,7 @@ get_parameters.mlm <- function(x, ...) {
       row.names = NULL
     )
 
-    .remove_backticks_from_parameter_names(params)
+    text_remove_backticks(params)
   })
 
   do.call(rbind, out)
@@ -441,7 +456,7 @@ get_parameters.gbm <- function(x, ...) {
     row.names = NULL
   )
 
-  .remove_backticks_from_parameter_names(params)
+  text_remove_backticks(params)
 }
 
 
@@ -457,7 +472,7 @@ get_parameters.BBreg <- function(x, ...) {
     row.names = NULL
   )
 
-  .remove_backticks_from_parameter_names(params)
+  text_remove_backticks(params)
 }
 
 
@@ -475,7 +490,7 @@ get_parameters.rma <- function(x, ...) {
       )
 
       params$Parameter[grepl("intrcpt", params$Parameter)] <- "(Intercept)"
-      .remove_backticks_from_parameter_names(params)
+      text_remove_backticks(params)
     },
     error = function(x) {
       NULL
@@ -498,7 +513,7 @@ get_parameters.meta_random <- function(x, ...) {
       )
 
       params$Parameter[grepl("d", params$Parameter)] <- "(Intercept)"
-      .remove_backticks_from_parameter_names(params)
+      text_remove_backticks(params)
     },
     error = function(x) {
       NULL
@@ -524,7 +539,7 @@ get_parameters.metaplus <- function(x, ...) {
   )
 
   params$Parameter[grepl("muhat", params$Parameter)] <- "(Intercept)"
-  .remove_backticks_from_parameter_names(params)
+  text_remove_backticks(params)
 }
 
 
@@ -604,7 +619,7 @@ get_parameters.lavaan <- function(x, ...) {
     stringsAsFactors = FALSE
   )
 
-  .remove_backticks_from_parameter_names(params)
+  text_remove_backticks(params)
 }
 
 
@@ -624,7 +639,7 @@ get_parameters.polr <- function(x, ...) {
     row.names = NULL
   )
 
-  .remove_backticks_from_parameter_names(params)
+  text_remove_backticks(params)
 }
 
 
@@ -640,7 +655,7 @@ get_parameters.bracl <- function(x, ...) {
     row.names = NULL
   )
 
-  .remove_backticks_from_parameter_names(params)
+  text_remove_backticks(params)
 }
 
 
@@ -665,7 +680,7 @@ get_parameters.aov <- function(x, ...) {
     row.names = NULL
   )
 
-  .remove_backticks_from_parameter_names(params)
+  text_remove_backticks(params)
 }
 
 
@@ -680,7 +695,7 @@ get_parameters.aovlist <- function(x, ...) {
       Group = i,
       stringsAsFactors = FALSE
     )
-    .remove_backticks_from_parameter_names(params)
+    text_remove_backticks(params)
   }))
   rownames(out) <- NULL
   out
@@ -700,7 +715,7 @@ get_parameters.manova <- function(x, ...) {
   pattern <- paste0("(", paste0(paste0(".", unique(out$Response)), collapse = "|"), ")$")
   out$Parameter <- gsub(pattern, "", out$Parameter)
 
-  .remove_backticks_from_parameter_names(out)
+  text_remove_backticks(out)
 }
 
 #' @export
@@ -737,7 +752,7 @@ get_parameters.pgmm <- function(x, component = c("conditional", "all"), ...) {
     params <- .remove_column(params, "Component")
   }
 
-  .remove_backticks_from_parameter_names(params)
+  text_remove_backticks(params)
 }
 
 
