@@ -16,7 +16,6 @@
 #' data(mtcars)
 #' m <- lm(mpg ~ wt + cyl + vs, data = mtcars)
 #' get_parameters(m)
-#' @importFrom stats coef
 #' @export
 get_parameters.gamm <- function(x, component = c("all", "conditional", "smooth_terms", "location"), ...) {
   x <- x$gam
@@ -77,7 +76,6 @@ get_parameters.vgam <- function(x, component = c("all", "conditional", "smooth_t
 
 
 
-#' @importFrom stats na.omit
 #' @export
 get_parameters.gamlss <- function(x, ...) {
   pars <- lapply(x$parameters, function(i) {
@@ -96,7 +94,7 @@ get_parameters.gamlss <- function(x, ...) {
       row.names = NULL
     )
 
-    .remove_backticks_from_parameter_names(params)
+    text_remove_backticks(params)
   }))
 
   # data.frame(
@@ -115,13 +113,12 @@ get_parameters.gamlss <- function(x, ...) {
 
 
 #' @rdname get_parameters.gamm
-#' @importFrom stats setNames
 #' @export
 get_parameters.rqss <- function(x, component = c("all", "conditional", "smooth_terms"), ...) {
   component <- match.arg(component)
   sc <- summary(x)
 
-  smooth_terms <- sc$qsstab[, 3]
+  smooth_terms <- sc$qsstab[, 1]
   names(smooth_terms) <- rownames(sc$qsstab)
 
   .return_smooth_parms(
@@ -133,7 +130,6 @@ get_parameters.rqss <- function(x, component = c("all", "conditional", "smooth_t
 
 
 
-#' @importFrom stats setNames
 #' @export
 get_parameters.cgam <- function(x, component = c("all", "conditional", "smooth_terms"), ...) {
   component <- match.arg(component)
@@ -152,6 +148,22 @@ get_parameters.cgam <- function(x, component = c("all", "conditional", "smooth_t
 }
 
 
+#' @export
+get_parameters.SemiParBIV <- function(x, ...) {
+  s <- summary(x)
+  s <- .compact_list(s[grepl("^tableP", names(s))])
+  params <- do.call(rbind, lapply(1:length(s), function(i) {
+    out <- as.data.frame(s[[i]])
+    out$Parameter <- rownames(out)
+    out$Component <- paste0("Equation", i)
+    out
+  }))
+  colnames(params)[1] <- "Estimate"
+  rownames(params) <- NULL
+  text_remove_backticks(params[c("Parameter", "Estimate", "Component")])
+}
+
+
 
 
 # helper -------------------
@@ -189,5 +201,5 @@ get_parameters.cgam <- function(x, component = c("all", "conditional", "smooth_t
     pars <- .remove_column(pars, "Component")
   }
 
-  .remove_backticks_from_parameter_names(pars)
+  text_remove_backticks(pars)
 }
