@@ -22,6 +22,8 @@
 #'   other models (e.g., `glm`), prediction intervals are somewhat useless
 #'   (for instance, for a binomial model for which the dependent variable is a
 #'   vector of 1s and 0s, the prediction interval is... `[0, 1]`).
+#' @param se Numeric vector of standard error of predicted values. If `NULL`,
+#'   standard errors are calculated based on the variance-covariance matrix.
 #' @param vcov_estimation Either a matrix, or a string, indicating the suffix
 #'   of the `vcov*()`-function from the \pkg{sandwich} or \pkg{clubSandwich}
 #'   package, e.g. `vcov_estimation = "CL"` (which calls
@@ -67,10 +69,10 @@
 #' predictions <- get_predicted(x, iterations = 500)
 #' get_predicted_ci(x, predictions)
 #'
-#' if (require("bayestestR")) {
+#' if (require("datawizard")) {
 #'   ci_vals <- get_predicted_ci(x, predictions, ci = c(0.80, 0.95))
 #'   head(ci_vals)
-#'   bayestestR::reshape_ci(ci_vals)
+#'   datawizard::reshape_ci(ci_vals)
 #'
 #'   ci_vals <- get_predicted_ci(x,
 #'     predictions,
@@ -96,6 +98,7 @@ get_predicted_ci <- function(x, predictions = NULL, ...) {
 
 
 
+
 # General method ----------------------------------------------------------
 
 #' @rdname get_predicted_ci
@@ -103,30 +106,42 @@ get_predicted_ci <- function(x, predictions = NULL, ...) {
 get_predicted_ci.default <- function(x,
                                      predictions = NULL,
                                      data = NULL,
+                                     se = NULL,
                                      ci = 0.95,
                                      ci_type = "confidence",
+                                     ci_method = "quantile",
+                                     dispersion_method = "sd",
                                      vcov_estimation = NULL,
                                      vcov_type = NULL,
                                      vcov_args = NULL,
-                                     dispersion_method = "sd",
-                                     ci_method = "quantile",
                                      ...) {
+  # sanity check, if CI should be skipped
+  if (is.null(ci)) {
+    return(ci)
+  }
+
   # If draws are present (bootstrapped or Bayesian)
   if ("iterations" %in% names(attributes(predictions))) {
     iter <- attributes(predictions)$iteration
-
     se <- .get_predicted_se_from_iter(iter = iter, dispersion_method)
     out <- .get_predicted_ci_from_iter(iter = iter, ci = ci, ci_method)
-
-    return(cbind(se, out))
+    out <- cbind(se, out)
+    # outcome is multinomial/ordinal/cumulative
+    if (inherits(predictions, "data.frame") &&
+      "Response" %in% colnames(predictions) &&
+      "Row" %in% colnames(predictions)) {
+      out <- cbind(predictions[, c("Row", "Response")], out)
+    }
+    return(out)
   }
 
   # Analytical solution
   # 1. Find appropriate interval function
-  if (ci_type == "confidence" || get_family(x)$family %in% c("gaussian") || (!is.null(vcov_estimation) && is.matrix(vcov_estimation))) { # gaussian or CI
+  if (!is.null(se)) {
+    ci_function <- .get_predicted_se_to_ci
+  } else if (ci_type == "confidence" || get_family(x)$family %in% c("gaussian") || (!is.null(vcov_estimation) && is.matrix(vcov_estimation))) { # gaussian or CI
     se <- get_predicted_se(
       x,
-      predictions,
       data = data,
       ci_type = ci_type,
       vcov_estimation = vcov_estimation,
@@ -157,169 +172,12 @@ get_predicted_ci.default <- function(x,
   out
 }
 
-
-# Specific definitions ----------------------------------------------------
-
 #' @export
 get_predicted_ci.mlm <- function(x, ...) {
   stop("TBD")
 }
 
 
-# Get Variance-covariance Matrix ---------------------------------------------------
-
-
-.get_predicted_ci_vcov <- function(x,
-                                   vcov_estimation = NULL,
-                                   vcov_type = NULL,
-                                   vcov_args = NULL) {
-
-  # (robust) variance-covariance matrix
-  if (!is.null(vcov_estimation) && !is.matrix(vcov_estimation)) {
-    # check for existing vcov-prefix
-    if (!grepl("^vcov", vcov_estimation)) {
-      vcov_estimation <- paste0("vcov", vcov_estimation)
-    }
-
-    # set default for clubSandwich
-    if (vcov_estimation == "vcovCR" && is.null(vcov_type)) {
-      vcov_type <- "CR0"
-    }
-
-    if (!is.null(vcov_type) && vcov_type %in% c("CR0", "CR1", "CR1p", "CR1S", "CR2", "CR3")) {
-      # installed?
-      check_if_installed("clubSandwich")
-      robust_package <- "clubSandwich"
-      vcov_estimation <- "vcovCR"
-    } else {
-      # installed?
-      check_if_installed("sandwich")
-      robust_package <- "sandwich"
-    }
-
-    # compute robust standard errors based on vcov
-    if (robust_package == "sandwich") {
-      vcov_estimation <- get(vcov_estimation, asNamespace("sandwich"))
-      vcovmat <- as.matrix(do.call(vcov_estimation, c(list(x = x, type = vcov_type), vcov_args)))
-    } else {
-      vcov_estimation <- clubSandwich::vcovCR
-      vcovmat <- as.matrix(do.call(vcov_estimation, c(list(obj = x, type = vcov_type), vcov_args)))
-    }
-  } else if (!is.matrix(vcov_estimation)) {
-    # get variance-covariance-matrix, depending on model type
-    vcovmat <- get_varcov(x, component = "conditional")
-  } else {
-    vcovmat <- vcov_estimation
-  }
-
-  vcovmat
-}
-
-
-# Get Model matrix ------------------------------------------------------------
-
-
-.get_predicted_ci_modelmatrix <- function(x, data = NULL, vcovmat = NULL, ...) {
-  resp <- find_response(x)
-  if (is.null(vcovmat)) vcovmat <- .get_predicted_ci_vcov(x, ...)
-
-
-  if (is.null(data)) {
-    mm <- get_modelmatrix(x)
-  } else {
-    if (!all(resp %in% data)) data[[resp]] <- 0 # fake response
-    # else, model.matrix below fails, e.g. for log-terms
-    attr(data, "terms") <- NULL
-
-    # In these models we need to drop offset from model_terms. To do this, we
-    # must construct the mm by calling `get_modelmatrix` on modified model
-    # terms.  When we do not need to drop offset terms, we call get_modelmatrix
-    # on the model itself. The latter strategy is safer in cases where `data`
-    # does not include all the levels of a factor variable.
-    if (inherits(x, c("zeroinfl", "hurdle", "zerotrunc"))) {
-
-      # model terms, required for model matrix
-      model_terms <- tryCatch(
-        {
-          stats::terms(x)
-        },
-        error = function(e) {
-          find_formula(x)$conditional
-        }
-      )
-
-      all_terms <- find_terms(x)$conditional
-      off_terms <- grepl("^offset\\((.*)\\)", all_terms)
-      if (any(off_terms)) {
-        all_terms <- all_terms[!off_terms]
-        # TODO: preserve interactions
-        vcov_names <- dimnames(vcovmat)[[1]][grepl(":", dimnames(vcovmat)[[1]], fixed = TRUE)]
-        if (length(vcov_names)) {
-          vcov_names <- gsub(":", "*", vcov_names, fixed = TRUE)
-          all_terms <- unique(c(all_terms, vcov_names))
-        }
-        off_terms <- grepl("^offset\\((.*)\\)", all_terms)
-        model_terms <- stats::reformulate(all_terms[!off_terms], response = find_response(x))
-      }
-      mm <- get_modelmatrix(model_terms, data = data)
-    } else {
-      mm <- get_modelmatrix(x, data = data)
-    }
-  }
-
-  # fix rank deficiency
-  if (ncol(vcovmat) < ncol(mm)) {
-    mm <- mm[, intersect(colnames(mm), colnames(vcovmat))]
-  }
-
-  mm
-}
-
-
-
-# Get SE ------------------------------------------------------------------
-
-get_predicted_se <- function(x,
-                             predictions = NULL,
-                             data = NULL,
-                             ci_type = "confidence",
-                             vcov_estimation = NULL,
-                             vcov_type = NULL,
-                             vcov_args = NULL) {
-
-  # Matrix-multiply X by the parameter vector B to get the predictions, then
-  # extract the variance-covariance matrix V of the parameters and compute XVX'
-  # to get the variance-covariance matrix of the predictions. The square-root of
-  # the diagonal of this matrix represent the standard errors of the predictions,
-  # which are then multiplied by 1.96 for the confidence intervals.
-
-  vcovmat <- .get_predicted_ci_vcov(
-    x,
-    vcov_estimation = vcov_estimation,
-    vcov_type = vcov_type,
-    vcov_args = vcov_args
-  )
-  mm <- .get_predicted_ci_modelmatrix(x, data = data, vcovmat = vcovmat)
-
-  # compute vcov for predictions
-  # Next line equivalent to: diag(M V M')
-  var_diag <- colSums(t(mm %*% vcovmat) * t(mm))
-
-  # add sigma to standard errors, i.e. confidence or prediction intervals
-  ci_type <- match.arg(ci_type, c("confidence", "prediction"))
-  if (ci_type == "prediction") {
-    if (is_mixed_model(x)) {
-      se <- sqrt(var_diag + get_variance_residual(x))
-    } else {
-      se <- sqrt(var_diag + get_sigma(x)^2)
-    }
-  } else {
-    se <- sqrt(var_diag)
-  }
-
-  se
-}
-
 
 
 ## Convert to CI -----------
@@ -334,6 +192,9 @@ get_predicted_se <- function(x,
   # TODO: Prediction interval for poisson: https://fromthebottomoftheheap.net/2017/05/01/glm-prediction-intervals-ii/
 
   # Sanity checks
+  if (!is.null(se)) {
+    se <- as.numeric(se)
+  }
   if (is.null(predictions)) {
     return(data.frame(SE = se))
   }
@@ -346,7 +207,7 @@ get_predicted_se <- function(x,
 
   # Return NA
   if (is.null(se)) {
-    ci_low <- ci_high <- rep(NA, length(predictions))
+    se <- ci_low <- ci_high <- rep(NA, length(predictions))
 
     # Get CI
     # TODO: Does this cover all the model families?
@@ -369,8 +230,8 @@ get_predicted_se <- function(x,
       }
     }
 
-    ci_low <- predictions - (se * crit_val)
-    ci_high <- predictions + (se * crit_val)
+    ci_low <- as.numeric(predictions - (se * crit_val))
+    ci_high <- as.numeric(predictions + (se * crit_val))
   }
 
   data.frame(SE = se, CI_low = ci_low, CI_high = ci_high)
@@ -378,6 +239,54 @@ get_predicted_se <- function(x,
 
 
 
+
+.get_predicted_se_to_ci_zeroinfl <- function(x,
+                                             predictions = NULL,
+                                             se = NULL,
+                                             ci = 0.95,
+                                             link_inv = NULL,
+                                             ...) {
+
+  # Sanity checks
+  if (is.null(predictions)) {
+    return(data.frame(SE = se))
+  }
+
+  if (is.null(ci)) {
+    return(data.frame(CI_low = predictions, CI_high = predictions))
+  } # Same as predicted
+
+  # Return NA
+  if (is.null(se)) {
+    se <- ci_low <- ci_high <- rep(NA, length(predictions))
+
+    # Get CI
+    # TODO: Does this cover all the model families?
+  } else {
+    crit_val <- stats::qnorm(p = (1 + ci) / 2)
+
+    if (length(predictions) != length(se)) {
+      # multiple length?
+      if (length(predictions) %% length(se) == 0) {
+        # for multiple length, SE and predictions may match, could be intended?
+        # could there be any cases where we have twice or x times the length of
+        # predictions as standard errors?
+        warning(format_message("Predictions and standard errors are not of the same length. Please check if you need the 'data' argument."), call. = FALSE)
+      } else {
+        stop(format_message("Predictions and standard errors are not of the same length. Please specify the 'data' argument."), call. = FALSE)
+      }
+    }
+
+    ci_low <- link_inv(predictions - (se * crit_val))
+    ci_high <- link_inv(predictions + (se * crit_val))
+  }
+
+  data.frame(SE = se, CI_low = ci_low, CI_high = ci_high)
+}
+
+
+
+
 # Get PI ------------------------------------------------------------------
 
 .get_predicted_pi_glm <- function(x, predictions, ci = 0.95, ...) {
@@ -404,6 +313,8 @@ get_predicted_se <- function(x,
 }
 
 
+
+
 # Interval helpers --------------------------------------------------------
 
 .get_predicted_se_from_iter <- function(iter, dispersion_method = "SD") {
@@ -427,6 +338,7 @@ get_predicted_se <- function(x,
 
 
 
+
 .get_predicted_ci_from_iter <- function(iter, ci = 0.95, ci_method = "quantile") {
 
   # Interval
@@ -444,9 +356,9 @@ get_predicted_se <- function(x,
     if (length(ci) == 1) names(out) <- c("Parameter", "CI_low", "CI_high")
   } else {
     # installed?
-    check_if_installed("bayestestR")
+    check_if_installed(c("bayestestR", "datawizard"))
     out <- as.data.frame(bayestestR::ci(as.data.frame(t(iter)), ci = ci, method = ci_method))
-    if (length(ci) > 1) out <- reshape_ci(out)
+    if (length(ci) > 1) out <- datawizard::reshape_ci(out)
   }
   out$Parameter <- out$CI <- NULL
   row.names(out) <- NULL
