@@ -5,7 +5,7 @@
 #'
 #' @inheritParams find_random
 #'
-#' @return The data from all random effects terms, as data frame. Or \code{NULL}
+#' @return The data from all random effects terms, as data frame. Or `NULL`
 #'    if model has no random effects.
 #'
 #' @examples
@@ -29,11 +29,21 @@
 #' }
 #' @export
 get_random <- function(x) {
+  UseMethod("get_random")
+}
+
+#' @export
+get_random.default <- function(x) {
   if (.is_empty_object(find_random(x))) {
     warning("No random effects found in model.")
     return(NULL)
   }
 
-
   get_data(x, effects = "random")
 }
+
+
+#' @export
+get_random.afex_aov <- function(x) {
+  get_data(x, shape = "long")[find_random(x, flatten = TRUE)]
+}
