@@ -12,8 +12,12 @@ osx <- tryCatch(
   }
 )
 
-if (requiet("testthat") &&
+.runThisTest <- Sys.getenv("RunAllinsightTests") == "yes"
+
+if (.runThisTest &&
+  requiet("testthat") &&
   requiet("insight") &&
+  requiet("lme4") &&
   requiet("ordinal")) {
   data(wine, package = "ordinal")
   data(soup)
@@ -178,7 +182,7 @@ if (requiet("testthat") &&
     expect_false(is_multivariate(m2))
   })
 
-  if (getRversion() >= "3.6.0" && !isTRUE(osx)) {
+  if (getRversion() > "3.6.3" && !isTRUE(osx)) {
     test_that("get_variance", {
       expect_equal(
         get_variance(m1),
