@@ -4,6 +4,7 @@ pkgs <- c(
   "lme4",
   "brms",
   "glmmTMB",
+  "pscl",
   "mgcv",
   "gamm4",
   "merTools",
@@ -99,11 +100,16 @@ test_that("get_predicted - glm", {
   ref <- predict(x, se.fit = TRUE, type = "response")
   rez <- as.data.frame(get_predicted(x, predict = "expectation"))
   expect_equal(nrow(rez), 32)
-  expect_equal(max(abs(ref$fit - rez$Predicted)), 0, tolerance = 1e-10)
-  expect_equal(max(abs(ref$se.fit - rez$SE)), 0, tolerance = 1e-10)
+  expect_equal(max(abs(ref$fit - rez$Predicted)), 0, tolerance = 1e-4)
+  expect_equal(max(abs(ref$se.fit - rez$SE)), 0, tolerance = 1e-4)
   ref <- as.data.frame(suppressWarnings(insight::link_inverse(x)(predict.lm(x, interval = "confidence"))))
   expect_equal(max(abs(ref$lwr - rez$CI_low)), 0, tolerance = 1e-2)
 
+  ref <- predict(x, se.fit = TRUE, type = "link")
+  rez <- as.data.frame(get_predicted(x, predict = "link"))
+  expect_equal(nrow(rez), 32)
+  expect_equal(max(abs(ref$fit - rez$Predicted)), 0, tolerance = 1e-4)
+  expect_equal(max(abs(ref$se.fit - rez$SE)), 0, tolerance = 1e-4)
 
   # Bootstrap
   set.seed(333)
@@ -204,7 +210,7 @@ test_that("get_predicted - lmerMod (log)", {
   expect_equal(nrow(as.data.frame(rez)), 32)
 
   # No random
-  rez2 <- insight::get_predicted(x, newdata = mtcars[c("am", "hp")])
+  rez2 <- insight::get_predicted(x, newdata = mtcars[c("am", "hp")], verbose = FALSE)
   expect_true(!all(is.na(as.data.frame(rez2))))
 })
 
@@ -259,10 +265,10 @@ test_that("get_predicted - glmmTMB", {
   expect_equal(nrow(as.data.frame(rez)), 32)
 
   # No random
-  rez <- insight::get_predicted(x, newdata = mtcars[c("am")])
+  rez <- insight::get_predicted(x, newdata = mtcars[c("am")], verbose = FALSE)
   expect_true(!all(is.na(as.data.frame(rez))))
   x <- glmmTMB::glmmTMB(Petal.Length ~ Petal.Width + (1 | Species), data = iris)
-  rez <- insight::get_predicted(x, data = data.frame(Petal.Width = c(0, 1, 2)))
+  rez <- insight::get_predicted(x, data = data.frame(Petal.Width = c(0, 1, 2)), verbose = FALSE)
   expect_equal(length(rez), 3)
 
   # vs. Bayesian
@@ -358,7 +364,7 @@ test_that("get_predicted - rstanarm", {
   rezpred2 <- summary(get_predicted(x, predict = "prediction", include_random = FALSE))
   expect_true(mean(abs(rezrela$Predicted - rezrela2$Predicted)) > 0)
   expect_true(mean(abs(rezpred$Predicted - rezpred2$Predicted)) > 0)
-  rezrela3 <- summary(get_predicted(x, predict = "expectation", data = mtcars["am"]))
+  rezrela3 <- summary(get_predicted(x, predict = "expectation", data = mtcars["am"]), verbose = FALSE)
   expect_equal(mean(abs(rezrela2$Predicted - rezrela3$Predicted)), 0, tolerance = 0.001)
 })
 
@@ -402,7 +408,6 @@ test_that("lm: get_predicted vs barebones `predict()`", {
   unknown1 <- as.data.frame(get_predicted(mod))
   unknown2 <- as.data.frame(get_predicted(mod, predict = "expectation"))
   unknown3 <- suppressWarnings(as.data.frame(get_predicted(mod, predict = "response")))
-  expect_warning(as.data.frame(get_predicted(mod, predict = "response")))
   expect_equal(unknown1$Predicted, known$fit[, "fit"], ignore_attr = TRUE)
   expect_equal(unknown1$SE, known$se.fit, ignore_attr = TRUE)
   expect_equal(unknown1$CI_low, known$fit[, "lwr"], ignore_attr = TRUE)
@@ -420,9 +425,7 @@ test_that("lm: get_predicted vs barebones `predict()`", {
 
 test_that("using both `predict` and `type` raises an informative error", {
   mod <- glm(am ~ hp + factor(cyl), family = binomial, data = mtcars)
-  expect_warning(expect_error(
-    get_predicted(mod, predict = "response", type = "response")
-  ))
+  expect_error(get_predicted(mod, predict = "response", type = "response"))
 })
 
 
@@ -445,8 +448,7 @@ test_that("`predict()` vs. `get_predicted` link equivalence", {
   known <- predict(mod, type = "response", se.fit = TRUE)
   unknown1 <- as.data.frame(get_predicted(mod, predict = "expectation"))
   unknown2 <- as.data.frame(get_predicted(mod, predict = NULL, type = "response"))
-  unknown3 <- suppressWarnings(as.data.frame(get_predicted(mod, predict = "response")))
-  expect_warning(as.data.frame(get_predicted(mod, predict = "response")))
+  unknown3 <- as.data.frame(get_predicted(mod, predict = "response"))
   expect_equal(unname(known$fit), unknown1$Predicted)
   expect_equal(unname(known$se.fit), unknown1$SE)
   expect_equal(unname(known$fit), unknown2$Predicted)
@@ -461,22 +463,19 @@ test_that("hurdle: get_predicted matches `predict()`", {
   data("bioChemists", package = "pscl")
   mod <- pscl::hurdle(art ~ phd + fem | ment, data = bioChemists, dist = "negbin")
   known <- predict(mod, type = "response")
-  unknown <- get_predicted(mod, predict = NULL, type = "response")
+  unknown <- get_predicted(mod, predict = "response")
   expect_equal(known, unknown, ignore_attr = TRUE)
   known <- predict(mod, type = "zero")
-  unknown <- get_predicted(mod, predict = NULL, type = "zero")
+  unknown <- get_predicted(mod, predict = "zero")
   expect_equal(known, unknown, ignore_attr = TRUE)
 })
 
 
 test_that("bugfix: used to return all zeros", {
   mod <- glm(am ~ hp + factor(cyl), family = binomial, data = mtcars)
-  expect_warning(get_predicted(mod, predict = "response"))
-  pred <- suppressWarnings(get_predicted(mod, predict = "response"))
+  pred <- get_predicted(mod, predict = "response")
   expect_false(any(pred == 0))
-  pred <- suppressWarnings(get_predicted(mod, predict = "original"))
-  expect_warning(get_predicted(mod, predict = "original"))
-  expect_false(all(pred == 0))
+  expect_error(expect_warning(get_predicted(mod, predict = "original")))
 })
 
 
@@ -492,8 +491,65 @@ test_that("brms: `type` in ellipsis used to produce the wrong intervals", {
   )
   x <- get_predicted(mod, predict = "link")
   y <- get_predicted(mod, predict = "expectation")
-  z <- get_predicted(mod, predict = NULL, type = "response")
-  expect_equal(round(x[1], 1), -1.4)
-  expect_equal(round(y[1], 1), .2)
-  expect_identical(y, z)
+  z <- get_predicted(mod, predict = NULL, type = "response", verbose = FALSE)
+  expect_equal(round(x[1], 1), -1.5, tolerance = 1e-1)
+  expect_equal(round(y[1], 1), .2, tolerance = 1e-1)
+  expect_equal(y, z, ignore_attr = TRUE)
+})
+
+
+test_that("zero-inflation stuff works", {
+  skip_if_not_installed("glmmTMB")
+  skip_if_not_installed("pscl")
+
+  data("fish")
+  m1 <- glmmTMB(
+    count ~ child + camper,
+    ziformula = ~ child + camper,
+    data = fish,
+    family = poisson()
+  )
+
+  m2 <- zeroinfl(
+    count ~ child + camper | child + camper,
+    data = fish,
+    dist = "poisson"
+  )
+
+  p1 <- head(predict(m1, type = "response"))
+  p2 <- head(predict(m2, type = "response"))
+  p3 <- head(get_predicted(m1))
+  p4 <- head(get_predicted(m2))
+
+  expect_equal(p1, p2, tolerance = 1e-1, ignore_attr = TRUE)
+  expect_equal(p1, p3, tolerance = 1e-1, ignore_attr = TRUE)
+  expect_equal(p1, p4, tolerance = 1e-1, ignore_attr = TRUE)
+  expect_equal(p2, p3, tolerance = 1e-1, ignore_attr = TRUE)
+  expect_equal(p2, p4, tolerance = 1e-1, ignore_attr = TRUE)
+  expect_equal(p3, p4, tolerance = 1e-1, ignore_attr = TRUE)
+
+  m1 <- glmmTMB(
+    count ~ child + camper,
+    ziformula = ~ child + camper,
+    data = fish,
+    family = truncated_poisson()
+  )
+
+  m2 <- hurdle(
+    count ~ child + camper | child + camper,
+    data = fish,
+    dist = "poisson"
+  )
+
+  p1 <- head(predict(m1, type = "response"))
+  p2 <- head(predict(m2, type = "response"))
+  p3 <- head(get_predicted(m1))
+  p4 <- head(get_predicted(m2))
+
+  expect_equal(p1, p2, tolerance = 1e-1, ignore_attr = TRUE)
+  expect_equal(p1, p3, tolerance = 1e-1, ignore_attr = TRUE)
+  expect_equal(p1, p4, tolerance = 1e-1, ignore_attr = TRUE)
+  expect_equal(p2, p3, tolerance = 1e-1, ignore_attr = TRUE)
+  expect_equal(p2, p4, tolerance = 1e-1, ignore_attr = TRUE)
+  expect_equal(p3, p4, tolerance = 1e-1, ignore_attr = TRUE)
 })
