@@ -1,6 +1,6 @@
-if (require("testthat") &&
-  require("insight") &&
-  require("lmtest")) {
+if (requiet("testthat") &&
+  requiet("insight") &&
+  requiet("lmtest")) {
   data("Mandible", package = "lmtest")
   m <- lm(length ~ age, data = Mandible, subset = (age <= 28))
   ct1 <- coeftest(m)
